<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ar">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="45"/>
        <source>&amp;About</source>
        <translation>&amp;حول</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="48"/>
        <source>Main developers</source>
        <translation>المطورون الرئيسيون</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="62"/>
        <source>A&amp;uthors</source>
        <translation>المؤلفون</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="66"/>
        <source>Translation</source>
        <translation>ترجمات</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="67"/>
        <source>Czech</source>
        <translation>التشيكية</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="68"/>
        <source>Slovenian</source>
        <translation>السلوفينية</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="69"/>
        <source>French</source>
        <translation>الفرنسية</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="77"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="78"/>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="79"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="80"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="81"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="82"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="83"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="85"/>
        <source>Logo</source>
        <translation>الشعار</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="87"/>
        <source>Coordinating</source>
        <translation>المنسقون</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="91"/>
        <source>Testing</source>
        <translation>المختبرون</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="103"/>
        <source>&amp;Thanks To</source>
        <translation>&amp;شكرا لكل من</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="108"/>
        <source>&amp;Licence Agreement</source>
        <translation>اتفاقية التر&amp;خيص</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="110"/>
        <source>OK</source>
        <translation>موافق</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="123"/>
        <source>About</source>
        <translation>حول</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="40"/>
        <source>This is the Stopmotion application for creating stop motion animations.</source>
        <translation>هذه برمجية Stopmotion لعمل تحريك بتقنية إيقاف الحركة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="70"/>
        <source>German</source>
        <translation>الألمانية</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="72"/>
        <source>Portuguese</source>
        <translation>البرتغالية</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="74"/>
        <source>Spanish</source>
        <translation>الإسبانية</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="75"/>
        <source>Swedish</source>
        <translation>السويدية</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="52"/>
        <source>Contributors</source>
        <translation>المساهمون</translation>
    </message>
</context>
<context>
    <name>DeviceTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="64"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="357"/>
        <source>Below you can set which device Stopmotion should use for grabbing images and displaying video.</source>
        <translation>فيما يلي يمكن تعيين النبيطة التي يلتقط stopmotion منها الصور و يعرض الفيديو.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="66"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="359"/>
        <source>You can select from the auto-detected devices below or add devices yourself. It is not recommended to use devices which is not auto-detected, but feel free to do it if you are an advanced user.</source>
        <translation>يمكن التعيين من بين النبائط المتحسسة تلقائيا المسرودة فيما يلي أو إضافة نبيطة بنفسك. لا ينصح باستخدام النبائط غير المتحسسة تلقائيا إلا إن كنت مستخدما متمرسا.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="69"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="362"/>
        <source>The selected device is recognized as &lt;b&gt;$VIDEODEVICE&lt;/b&gt; under Video Import.</source>
        <translation>النبيطة التي اخترتها معرّفة بالاسم &lt;b&gt;$VIDEODEVICE&lt;/b&gt; تحت مستوردات الفيديو.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="75"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="366"/>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="75"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="366"/>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="89"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="369"/>
        <source>&amp;Add</source>
        <translation>&amp;أضف</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="93"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="370"/>
        <source>&amp;Remove</source>
        <translation>أ&amp;زِل</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="96"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="371"/>
        <source>&amp;Edit</source>
        <translation>&amp;حرّر</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="100"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="374"/>
        <source>Video device settings</source>
        <translation>إعدادات نبيطة الفيديو</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="109"/>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="375"/>
        <source>Video Device ($VIDEODEVICE): </source>
        <translation>نبيطة الفيديو ($VIDEODEVICE):</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="157"/>
        <source>device</source>
        <translation>النبيطة</translation>
    </message>
</context>
<context>
    <name>ExportTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="382"/>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="382"/>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="83"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="385"/>
        <source>&amp;Add</source>
        <translation>&amp;أضف</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="87"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="386"/>
        <source>&amp;Remove</source>
        <translation>&amp;أزِل</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="90"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="387"/>
        <source>&amp;Edit</source>
        <translation>&amp;حرر</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="94"/>
        <source>Encoder settings</source>
        <translation>إعدادات الترميز</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="104"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="390"/>
        <source>Do you want to be asked for an output file every time you choose to export?</source>
        <translation>أتريد تعيين ملف الإخراج قبل كل تصدير؟</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="106"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="392"/>
        <source>Yes</source>
        <translation>نعم</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="111"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="393"/>
        <source>No</source>
        <translation>لا</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="116"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="394"/>
        <source>Set default output file:</source>
        <translation>عيّن ملف الإخراج المبدئي:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="122"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="395"/>
        <source>Browse</source>
        <translation>تصفّح</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="127"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="396"/>
        <source>Start encoder:</source>
        <translation>شغّل  المُرمِّز:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="132"/>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="397"/>
        <source>Stop encoder:</source>
        <translation>أوقف المُرمِّز:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="361"/>
        <source>Choose output file</source>
        <translation>عيّن ملف الإخراج</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="371"/>
        <source>Below you can set which program/process Stopmotion should use for encoding the currently active project to a video file.</source>
        <translation>فيما يلي يمكن تعيين أي البرمجيات/الصيرورات ينبغي استخدامها لترميز المشروع الحالي إلى ملف فيديو.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="373"/>
        <source>You should always use &lt;b&gt;$IMAGEPATH&lt;/b&gt; and &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the image path and the video file, respectively.</source>
        <translation>ينبغي استخدام &lt;b&gt;$IMAGEPATH&lt;/b&gt; للدلالة على مسار الصور، و &lt;b&gt;$VIDEOFILE&lt;/b&gt; للدلالة على مسار ملف الفيديو.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="375"/>
        <source>You can use &lt;b&gt;$FRAMERATE&lt;/b&gt; to represent the frame rate currently in use in the project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="377"/>
        <source>Example with mencoder (jpeg images to mpeg4 video):</source>
        <translation>مثال باستخدام mencoder (من صور بصيغة jpeg إلى فيديو بصيغة mpeg4):</translation>
    </message>
</context>
<context>
    <name>ExternalCommand</name>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="44"/>
        <source>Input to program:</source>
        <translation>مُدخل إلى البرمجية:</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="54"/>
        <source>Submit</source>
        <translation>أودِع</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="60"/>
        <source>Close</source>
        <translation>أغلِق</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="73"/>
        <source>Output from external command</source>
        <translation>أخرج عبر برمجية خارجية</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="115"/>
        <location filename="../src/application/externalcommand.cpp" line="118"/>
        <source>Result</source>
        <translation>النتيجة</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="115"/>
        <source>Failed!</source>
        <translation>فشلت العملية!</translation>
    </message>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="118"/>
        <source>Successful!</source>
        <translation>تمّت العملية بنجاح!</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="32"/>
        <source>Form</source>
        <translation>استمارة</translation>
    </message>
</context>
<context>
    <name>FrameBar</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framebar/framebar.cpp" line="194"/>
        <source>Frame number: </source>
        <translation>رقم الإطار:</translation>
    </message>
</context>
<context>
    <name>FramePreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="114"/>
        <source>Add &amp;sound</source>
        <translation>أضف &amp;صوتا</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="115"/>
        <source>&amp;Remove Sound</source>
        <translation>أ&amp;زل الصوت</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="116"/>
        <source>Change name</source>
        <translation>غيّر الاسم</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="117"/>
        <source>Sounds:</source>
        <translation>الأصوات:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="120"/>
        <source>&lt;h4&gt;Add sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;add sounds&lt;/em&gt; to the selected frame.&lt;/p&gt; &lt;p&gt;The sound will begin playing when this frame is shown and play until it is done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;أضِف صوتا&lt;/h4&gt; &lt;p&gt;باستخدام هذا الزر تمكن &lt;em&gt;إضافة أصوات&lt;/em&gt; إلى الإطار الذي تختاره.&lt;/p&gt; &lt;p&gt;الصوت سيبدأ إصداره مع ظهور هذا الإطار مستمرا حتى إنتهاءه.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="128"/>
        <source>&lt;h4&gt;Remove sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;remove&lt;/em&gt; the selected sound from this frame.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;أزل الصوت&lt;/h4&gt; &lt;p&gt;يمكن باستخدام هذا الزر أن &lt;em&gt;تزيل&lt;/em&gt; الصوت عن هذا الإطار.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="135"/>
        <source>&lt;h4&gt;Change name&lt;/h4&gt; &lt;p&gt;With this button you can change the name of the selected sound. &lt;BR&gt;The name of the sound has no other effect than making it easier work with the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;غيّر الاسم&lt;/h4&gt; &lt;p&gt;باستخدام هذا الزر يمكن تغيير اسم الصوت المُعيَّن &lt;BR&gt;لا تأثير لتغيير الاسم سوى تسهيل العمل.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="143"/>
        <source>&lt;h4&gt;Sounds&lt;/h4&gt; &lt;p&gt;This lists shows all the sounds connected to this frame.&lt;/p&gt;&lt;p&gt;The sounds will begin playing when this frame is shown and play until they are done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;&lt;h4&gt;الأصوات&lt;/h4&gt; &lt;p&gt;هذه القائمة تظهر كل الأصوات المرتبطة بهذا الإطار.&lt;/p&gt;&lt;p&gt;سيبدأ تشغيل الصوت مع ظهور هذا الإطار وسيستمر حتى إنتهاءه.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FrameView</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="290"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="304"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="317"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="360"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="372"/>
        <source>Warning</source>
        <translation>تنبيه</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="360"/>
        <source>Grabbing failed. This may happen if you try
to grab from an invalid device. Please check
your grabber settings in the preferences menu.</source>
        <translation>فشل التقاط الصورة، قد يحدث هذا إن كنت تحاول
الالتقاط من نبيطة غير صحيحة. تأكد من إعدادات
 الالتقاط في قائمة التفضيلات.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="372"/>
        <source>You have to define an image grabber to use.
This can be set in the preferences menu.</source>
        <translation>ينبغي عليك تعيين لاقط للصور لاستخدام هذه الوظيفة.
يمكن تعيين اللاقط في قائمة التفضيلات.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="304"/>
        <source>Pre poll command does not exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="317"/>
        <source>You do not have the given grabber installed on your system</source>
        <translatorcomment>اللاقط المعيّن ليس متصلا بهذا النظام</translatorcomment>
        <translation>المغتنم المعين غير مثبت على هذا النظام.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="290"/>
        <source>No video device selected in the preferences menu.</source>
        <translation>لا نبائط فيديو مُعيّنة في قائمة التفضيلات.</translation>
    </message>
</context>
<context>
    <name>ImportTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="67"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="321"/>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="67"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="321"/>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="83"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="324"/>
        <source>&amp;Add</source>
        <translation>أ&amp;ضف</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="87"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="325"/>
        <source>&amp;Remove</source>
        <translation>أ&amp;زل</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="90"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="326"/>
        <source>&amp;Edit</source>
        <translation>&amp;حرّر</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="94"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="328"/>
        <source>Import device settings</source>
        <translation>اسّتورد إعدادات النبيطة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="103"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="329"/>
        <source>Pre-poll command</source>
        <translation>أمر ما قبل الالتقاط</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="110"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="330"/>
        <source>Start daemon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="117"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="331"/>
        <source>Stop daemon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start deamon</source>
        <translation type="obsolete">شغّل الجنيّ</translation>
    </message>
    <message>
        <source>Stop deamon</source>
        <translation type="obsolete">أوقف الجنيّ</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="59"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="315"/>
        <source>Below you can set which program/process Stopmotion should use for grabbing images from the selected device.</source>
        <translation>أدناه يمكنك تحديد أي البرمجيات/الصيرورات على stopmotion استخدامها لالتقاط الصور من النبيطة المُعيّنة.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="61"/>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="317"/>
        <source>You should always use &lt;b&gt;$VIDEODEVICE&lt;/b&gt; and &lt;b&gt;$IMAGEFILE&lt;/b&gt; to represent the video device and the image file, respectively.</source>
        <translation>ينبغي عليك دوما إستخدام &lt;b&gt;$VIDEODEVICE&lt;/b&gt; للدلالة على نبيطة الفيديو و &lt;b&gt;$IMAGEFILE&lt;/b&gt; للدلالة على ملف الصورة.</translation>
    </message>
</context>
<context>
    <name>LanguageHandler</name>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="87"/>
        <source>English</source>
        <translation>العربية</translation>
    </message>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="89"/>
        <source>&amp;Translation</source>
        <translation>&amp;ترجمات</translation>
    </message>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="105"/>
        <source>English</source>
        <comment>This should be translated to the name of the language you are translating to, in that language. Example: English = Deutsch (Deutsch is &quot;German&quot; in German)</comment>
        <translation type="unfinished">العربية</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="16"/>
        <source>Stopmotion Help Browser</source>
        <translation>متصفح مساعدة Stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="40"/>
        <source>Backward</source>
        <translation>السابق</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="50"/>
        <source>Forward</source>
        <translation>اللاحق</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="86"/>
        <source>Close</source>
        <translation>أغلِق</translation>
    </message>
</context>
<context>
    <name>MainWindowGUI</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="153"/>
        <source>Ready to rumble ;-)</source>
        <translation>جاهز للانطلاق ;-)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="503"/>
        <source>&amp;New</source>
        <translation>&amp;جديد</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="504"/>
        <source>&amp;Open</source>
        <translation>ا&amp;فتح</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="590"/>
        <source>&lt;h4&gt;Open&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Opens&lt;/em&gt; a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;افتح&lt;/h4&gt; &lt;p&gt;ملف مشروع stopmotion.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="505"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>&amp;Save</source>
        <translation>ا&amp;حفظ</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="506"/>
        <source>Save &amp;As</source>
        <translation>ا&amp;حفظ باسم</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="509"/>
        <source>&amp;Quit</source>
        <translation>أ&amp;نهِ</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="631"/>
        <source>&lt;h4&gt;Quit&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Quits&lt;/em&gt; the program.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;أنهِ&lt;/h4&gt; &lt;p&gt;البرمجية.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="374"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="534"/>
        <source>&amp;File</source>
        <translation>&amp;ملف</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="510"/>
        <source>&amp;Undo</source>
        <translation>&amp;تراجع</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="641"/>
        <source>&lt;h4&gt;Undo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Undoes&lt;/em&gt; your last operation. You can press undo several time to undo earlier operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;تراجع&lt;/h4&gt; &lt;p&gt;عن آخر عملية أجريتها. يمكن ضغط &lt;em&gt;تراجع&lt;/em&gt; أكثر من مرة للتراجع عن عمليات سابقة.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="511"/>
        <source>Re&amp;do</source>
        <translation>أعِد</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="650"/>
        <source>&lt;h4&gt;Redo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Redoes&lt;/em&gt; your last operation. You can press redo several times to redo several operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;أعِد&lt;/h4&gt; &lt;p&gt; إجراء آخر عملية أجريتها. يمكن الضغط على أعِد أكثر من مرة لإعادة أكثر من إجراء تراجعت عنه.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="512"/>
        <source>Cu&amp;t</source>
        <translation>ق&amp;ص</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="659"/>
        <source>&lt;h4&gt;Cut&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Cuts&lt;/em&gt; the selected frames out of the animation and adds them to the clipboard so that you can paste them in somewhere else.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;قصّCut&lt;/h4&gt; &lt;p&gt;الأطر المعيّنة من التحريك إلى الحافظة لإمكان لصقها لاحقا في مكان آخر.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="513"/>
        <source>&amp;Copy</source>
        <translation>ان&amp;سخ</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="668"/>
        <source>&lt;h4&gt;Copy&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Copies&lt;/em&gt; the selected frames to the clipboard. You can then paste them in another place.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;انسخ&lt;/h4&gt; &lt;p&gt;الأطر المُعيَّنة من التحريك إلى الحافظة ﻹمكان لصقها لاحقا في مكان آخر&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="514"/>
        <source>&amp;Paste</source>
        <translation>أ&amp;لصِق</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="677"/>
        <source>&lt;h4&gt;Paste&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Pastes&lt;/em&gt; the frames which are currently in the clipboard into the selected location.&lt;/p&gt; &lt;p&gt;You can copy/cut images from another programs and then use this option to paste them into this animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;ألصِق&lt;/h4&gt; &lt;p&gt;الأطر من الحافظة إلى الموضع المُعيَّن.&lt;/p&gt; &lt;p&gt;يمكن نسخ/قص الصور من برمجية أخرى ثم استخدام هذا الخيار للصقها في التحريك.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="515"/>
        <source>&amp;Go to frame</source>
        <translation>انتقل إلى الإ&amp;طار</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="687"/>
        <source>&lt;h4&gt;Go to frame&lt;/h4&gt; &lt;p&gt;This will bring up a popup-menu at the bottom where you can choose a frame you want to &lt;em&gt;go to&lt;/em&gt;.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;انتقل إلى الإطار&lt;/h4&gt; &lt;p&gt; الذي تختاره من قائمة الإطارات الموجودة.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="378"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="563"/>
        <source>&amp;Edit</source>
        <translation>&amp;حرّر</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="395"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="558"/>
        <source>&amp;Settings</source>
        <translation>إ&amp;عدادات</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="517"/>
        <source>What&apos;s &amp;This</source>
        <translation>ما &amp;هذا</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="707"/>
        <source>&lt;h4&gt;What&apos;s This&lt;/h4&gt; &lt;p&gt;This will give you a WhatsThis mouse cursor which can be used to bring up helpful information like this.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;ما هذا&lt;/h4&gt; &lt;p&gt;يظهر مؤشر &quot;ما هذا؟&quot; الذي يظهر معلومات مفيدة كهذه.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="519"/>
        <source>&amp;About</source>
        <translation>ح&amp;ول</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="724"/>
        <source>&lt;h4&gt;About&lt;/h4&gt; &lt;p&gt;This will display a small information box where you can read general information as well as the names of the developers behind this excellent piece of software.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;حول&lt;/h4&gt;&lt;p&gt;يعرض صندوق معلومات صغير فيه معلومات عن البرمجية و أسماء المبرمجين و المترجمين و المساهمين في تطويرها&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="398"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="518"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="565"/>
        <source>&amp;Help</source>
        <translation>مساع&amp;دة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="769"/>
        <source>&lt;h4&gt;FrameBar&lt;/h4&gt; &lt;p&gt;In this area you can see the frames and scenes in the animations and build the animation by moving the them around.&lt;/p&gt;&lt;p&gt;You can switch to the next and the previous frame using the &lt;b&gt;arrow buttons&lt;/b&gt; or &lt;b&gt;x&lt;/b&gt; and &lt;b&gt;z&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;h4&gt;شريط الإطارات&lt;/h4&gt; &lt;p&gt; في هذه المساحة ترى الإطارات و المشاهد في التحريكات و تبني التحريك بنقلها و ترتيبها.&lt;/p&gt;&lt;p&gt;يمكنك الانتقال إلى الالإطار اللاحق و السابق باستخدام &lt;b&gt;أزرار الأسهم&lt;/b&gt; أو &lt;b&gt;x&lt;/b&gt; و &lt;b&gt;z&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="763"/>
        <source>&lt;h4&gt;Tool menu&lt;/h4&gt; &lt;p&gt;This is the tool menu where most of the buttons and widgets you will need when working on stop motion animations are located.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;قائمة الأدوات&lt;/h4&gt;&lt;p&gt;هذه قائمة الأدوات حيث معظم الأزرار و التحكمات التي تستخدمها في العمل على تحريك&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="756"/>
        <source>&lt;h4&gt;Frame preferences menu&lt;/h4&gt; &lt;p&gt;In this menu you can set preferences for the selected frame/frames, such as &lt;b&gt;subtitles&lt;/b&gt;, &lt;b&gt;sound effects&lt;/b&gt;, etc.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;قائمة تفضيلات الإطار&lt;/h4&gt; &lt;p&gt;من هذه القائمة يمكن تعيين تفضيلات الإطارات المُعيَّنة، مثل  &lt;b&gt;نص الترجمة&lt;/b&gt; و &lt;b&gt;المؤثرات الصوتية&lt;/b&gt;، إلخ.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="750"/>
        <source>&lt;h4&gt;Go to frame menu&lt;/h4&gt; &lt;p&gt;Here you can specify a framenumber and the program will jump to the specified frame&lt;/p&gt; </source>
        <translation>&lt;h4&gt;قائمة الانتقال إلى إطار&lt;/h4&gt; &lt;p&gt;بتعيين رقم إطار هنا فإنك تنتقل للعمل عليه&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="524"/>
        <source>Go to frame:</source>
        <translation>انتقل إلى الإطار:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="736"/>
        <source>&lt;h4&gt;Frame number&lt;/h4&gt;&lt;p&gt;This area displays the numberof the currently selected frame&lt;/p&gt;</source>
        <translation>&lt;h4&gt;رقم الإطار&lt;/h4&gt;&lt;p&gt;تظهر هذه المنطقة رقم الإطار المُعيَّن&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="743"/>
        <source>&lt;h4&gt;FrameView&lt;/h4&gt;&lt;p&gt; In this area you can see the selected frame. You can also play animations in this window by pressing the &lt;b&gt;Play&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;منظور الإطارات&lt;/h4&gt;&lt;p&gt;هنا ترى الإطار المُعيّن، يمكنك تشغيل التحريك في هذه النافذة بضغط زرّ &lt;b&gt;شغِّل&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="782"/>
        <source>Unsaved changes</source>
        <translation>تغييرات غير محفوظة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="783"/>
        <source>There are unsaved changes. Do you want to save?</source>
        <translation>توجد تغييرات غير محفوظة. أتودّ حفظها؟</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="916"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="966"/>
        <source>&amp;Yes</source>
        <translation>&amp;نعم</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="916"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="966"/>
        <source>&amp;No</source>
        <translation>&amp;لا</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="507"/>
        <source>Video</source>
        <translation>فيديو</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="375"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="547"/>
        <source>&amp;Export</source>
        <translation>صَدّر</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="581"/>
        <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;جديد&lt;/h4&gt; &lt;p&gt;ينشئ مشروعا  &lt;em&gt;جديدا&lt;/em&gt; .&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automaticly be saved to the previously selected file.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;احفظ&lt;/h4&gt; &lt;p&gt;&lt;em&gt;يحفظ&lt;/em&gt; التحريك الحالي كملف مشروع تحريك. &lt;BR&gt;إن كان المشروع قد حُفظ مسبقا فسيتم تحديثه في ذات الملف الذي حفظ فيه مسبقا.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="608"/>
        <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;&gt;احفظ باسم&lt;/h4&gt; &lt;p&gt;&lt;em&gt;يحفظ&lt;/em&gt;التحريك الحالي كملف مشروع تحريك جديد.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="617"/>
        <source>&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Exports the current project as &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;فيديو&lt;/h4&gt; &lt;p&gt;يصدّر المشروع الحالي &lt;em&gt;كفيديو&lt;/em&gt;.&lt;/p&gt;سيظهر مرشد ليدلك.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="624"/>
        <source>&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;Exports the current animation as a &lt;em&gt;Cinerella&lt;/em&gt; project.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation type="unfinished">&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;صدّر التحريك الحالي كمشروع  &lt;em&gt;Cinerella&lt;/em&gt; .&lt;/p&gt;سيظهر لك مرشد ليدلك.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="508"/>
        <source>Cinelerra</source>
        <translation>Cinelerra</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="516"/>
        <source>&amp;Configure Stopmotion</source>
        <translation>إعدادات stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="376"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="1148"/>
        <source>Open &amp;Recent</source>
        <translation>افتح الأخيرة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="586"/>
        <source>New project</source>
        <translation>مشروع جديد</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="594"/>
        <source>Open project</source>
        <translation type="unfinished">افتح مشروعا</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="598"/>
        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="604"/>
        <source>Save project</source>
        <translation>احفظ المشروع</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="613"/>
        <source>Save project As</source>
        <translation type="unfinished">احفظ المشروع باسم</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="635"/>
        <source>Quit</source>
        <translation type="unfinished">أنهِ</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="646"/>
        <source>Undo</source>
        <translation>تراجع</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="655"/>
        <source>Redo</source>
        <translation>أعِد</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="664"/>
        <source>Cut</source>
        <translation>قُصّ</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="673"/>
        <source>Copy</source>
        <translation>انسخ</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="683"/>
        <source>Paste</source>
        <translation>ألصِق</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="692"/>
        <source>Go to frame</source>
        <translation>انتقل إلى إطار</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="696"/>
        <source>&lt;h4&gt;Configure Stopmotion&lt;/h4&gt; &lt;p&gt;This will opens a window where you can &lt;em&gt;configure&lt;/em&gt; Stopmotion with various input and output devices.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;اضبط Stopmotion&lt;/h4&gt;&lt;p&gt;يفتح هذا نافذة يمكن فيها ضبط Stopmotion للعمل مع نبائط إدخال و إخراج متعددة&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="701"/>
        <source>Configure Stopmotion</source>
        <translation>إعدادات stopmotion</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="712"/>
        <source>What&apos;s This</source>
        <translation>ما هذا</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="730"/>
        <source>About</source>
        <translation>حول</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>Do&amp;n&apos;t save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="784"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="911"/>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="963"/>
        <source>Warning</source>
        <translation>تنبيه</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="912"/>
        <source>Cannot find any registered encoder to be used for
video export. This can be set in the preferences
menu. Export to video will not be possible until you
have set an encoder to use. Do you want to set it now?</source>
        <translation>تعذّر إيجاد أي مرمّز لاستخدامه لتصدير الفيديو.
يمكن ذبط ذلك في قائمة التفضيلات. تصدير فيديو
لن يكون ممكنا حتى تعيين مرمّز .
هل تود تعيينه الآن؟</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="948"/>
        <source>Export to video file</source>
        <translation>صَدّر إلى ملف فيديو</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="964"/>
        <source>The registered encoder is not valid. Do you want
to check your settings in the preferences menu?</source>
        <translation>مُرمِّزُ الفيديو المسجّل غير صحيح.
أتريد التحقق من التضبيطات في قائمة الإعدادات؟</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="980"/>
        <source>Export to file</source>
        <translation>صَدّر إلى ملف</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="716"/>
        <source>&lt;h4&gt;Help&lt;/h4&gt; &lt;p&gt;This button will bring up a dialog with the Stopmotion manual&lt;/p&gt;</source>
        <translation>&lt;h4&gt;مساعدة&lt;/h4&gt; &lt;p&gt;يظهر هذا الزر مربعا فيه دليل استخدام stopmotion&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="720"/>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="522"/>
        <source>Frame number: </source>
        <translation>رقم الإطار:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="816"/>
        <source>Choose project file</source>
        <translation>اختر ملف المشروع</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="884"/>
        <source>Save As</source>
        <translation>احفظ باسم</translation>
    </message>
</context>
<context>
    <name>ModelHandler</name>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="58"/>
        <source>Choose frames to add</source>
        <translation>عيّن إطارًا لإضافته</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="179"/>
        <source>Removed the selected frame</source>
        <translation>أزِل الإطار المُعيّن</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="216"/>
        <location filename="../src/application/modelhandler.cpp" line="227"/>
        <location filename="../src/application/modelhandler.cpp" line="244"/>
        <source>Warning</source>
        <translation>تنبيه</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="217"/>
        <source>You do not have Gimp installed on your system</source>
        <translation>گِمب ليس مُنصّبا على هذا النظام</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="228"/>
        <source>There is no active frame to open</source>
        <translation>ليس هناك إطار فاعل لفتحه</translation>
    </message>
    <message>
        <source>The active frame is corrupt</source>
        <translation type="obsolete">الإطار المُعيّن معطوب</translation>
    </message>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="245"/>
        <source>Failed to start Gimp!</source>
        <translation>فشل تشغيل گِمب!</translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="73"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="119"/>
        <source>Video &amp;Import</source>
        <translation>ا&amp;ستورد فيديو</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="82"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="120"/>
        <source>Video &amp;Export</source>
        <translation>&amp;صَدّر فيديو</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="39"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="114"/>
        <source>Apply</source>
        <translation>طبّق</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="43"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="115"/>
        <source>Close</source>
        <translation>أغلِق</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="57"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="116"/>
        <source>Preferences Menu</source>
        <translation>قائمة التفضيلات</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="91"/>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="118"/>
        <source>Video &amp;Device</source>
        <translation>نبي&amp;طة الفيديو</translation>
    </message>
</context>
<context>
    <name>QtFrontend</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="192"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="207"/>
        <source>Warning</source>
        <translation>تنبيه</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="196"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="204"/>
        <source>Fatal</source>
        <translation>خطأ فادح</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="120"/>
        <source>Cancel</source>
        <translation>ألغِ</translation>
    </message>
    <message>
        <source>vgrabbj VGA singleshot</source>
        <translation type="obsolete">تشغيل vgrabbj للقطة VGA ,واحدة</translation>
    </message>
    <message>
        <source>Starts vgrabbj as a deamon. Pretty fast.</source>
        <translation type="obsolete">يشغّل vgrabbj كجنيّ. سريع للغاية.</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="418"/>
        <source>Question</source>
        <translation>سؤال</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="271"/>
        <source>The simplest setting. Fairly slow</source>
        <translation>الإعدادات الأبسط. بطيئة إلى حد ما</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="101"/>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="104"/>
        <source>Connecting camera...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="107"/>
        <source>Importing frames from disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="110"/>
        <source>Exporting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="113"/>
        <source>Restoring project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="116"/>
        <source>Saving scenes to disk...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="269"/>
        <source>vgrabbj</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="278"/>
        <source>vgrabbj VGA daemon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="280"/>
        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="288"/>
        <source>uvccapture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="290"/>
        <source>Grabbing from V4L2 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="324"/>
        <source>Exports from jpeg images to mpeg1 video</source>
        <translation>يصدر من صور jpeg إلى فيديو mpeg1</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="368"/>
        <source>Stopmotion cannot be started; it seems like it is already running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="411"/>
        <source>A newer version of the preferences file with few more default
values exists. Do you want to use this one? (Your old preferences
 will be saved in ~/.stopmotion/preferences.xml.OLD)</source>
        <translation>توجد نسخة جديدة من ملف الإعدادات تحوي بضع قيم مبدئية جديدة، أتريد استخدامها؟ (النسخة القديمة ستُحفظ في ~/stopmotion/preferences.xml.OLD)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="333"/>
        <source>Exports from jpeg images to mpeg2 video</source>
        <translation>تصدير من صور jpeg إلى فيديو mpeg2</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="342"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="351"/>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="359"/>
        <source>Exports from jpeg images to mpeg4 video</source>
        <translation>تصدير من صور jpeg إلى فيديو mpeg4</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="306"/>
        <source>dvgrab</source>
        <translation></translation>
    </message>
    <message>
        <source>Grabbing from DV-cam. (EXPERIMENTAL)</source>
        <translation type="obsolete">يجري الالتقاط من كاميرا DV (تجريبي)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="297"/>
        <source>videodog singleshot</source>
        <translation>استخدام videodog للقطة واحدة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="299"/>
        <source>Videodog.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="308"/>
        <source>Grabbing from DV-cam.</source>
        <translation>يجري الالتقاط من كاميرا DV.</translation>
    </message>
</context>
<context>
    <name>RunAnimationHandler</name>
    <message>
        <location filename="../src/application/runanimationhandler.cpp" line="90"/>
        <source>Running animation</source>
        <translation>يجري عرض التحريك</translation>
    </message>
</context>
<context>
    <name>SoundHandler</name>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="44"/>
        <source>Sounds (*.ogg)</source>
        <translation>أصوات (*.ogg)</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="70"/>
        <source>Sound name</source>
        <translation>اسم الصوت</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="71"/>
        <source>Enter the name of the sound:</source>
        <translation>أدخل اسما للصوت:</translation>
    </message>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="44"/>
        <source>Choose sound file</source>
        <translation>اختر ملف صوت</translation>
    </message>
</context>
<context>
    <name>ToolsMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="223"/>
        <source>FPS chooser</source>
        <translation>منتقي عدد الأطر في الثانية</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="301"/>
        <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;اختيار عدد الأطر في الثانية&lt;/h4&gt; &lt;p&gt;بتغيير القيمة في واجهة الاختيار فإنك تعيّن سرعة التحريك في &lt;b&gt;إطار العرض&lt;/b&gt; .&lt;/p&gt; &lt;p&gt;لبدء تشغيل التحريك اضغط زر &lt;b&gt;شغّل التحريك&lt;/b&gt; .&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="224"/>
        <source>Number of images:</source>
        <translation>عدد الصور:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="227"/>
        <source>Mix</source>
        <translation>امزج</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="228"/>
        <source>Diff</source>
        <translation>الفرق</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="229"/>
        <source>Playback</source>
        <translation>شغّل</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="234"/>
        <source>Per second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="235"/>
        <source>Per minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="236"/>
        <source>Per hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="241"/>
        <source>&lt;h4&gt;Add Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;أضف أطرا (CTRL+F)&lt;/h4&gt; &lt;p&gt;اضغط هذا الزر &lt;em&gt;لإضافة&lt;/em&gt; أطر إلى هذا التحريك.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="248"/>
        <source>&lt;h4&gt;Remove Selection (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;أزل الاختيار (Delete)&lt;/h4&gt; &lt;p&gt;اضغط هذا الزر &lt;em&gt;لإزالة&lt;/em&gt; الإطارات المُعيّنة من التحريك.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="255"/>
        <source>&lt;h4&gt;New Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;أضف مشهدًا (CTRL+E)&lt;/h4&gt; &lt;p&gt;اضغط هذا الزر &lt;em&gt;لإنشاء&lt;/em&gt;  &lt;em&gt;مشهد]&lt;/em&gt; جديدٍ في هذا التحريك.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="262"/>
        <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected scene from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;أزِل مشهدًا (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;اضغط هذا الزر &lt;em&gt;لإزالة&lt;/em&gt; المشهد المُعيّن من هذا التحريك.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="269"/>
        <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
        <translation>&lt;h4&gt;راوِح حالة تغيل الكاميرا (C)&lt;/h4&gt;&lt;p&gt;اضغط هذا الزر لمراوحة حالة الكامرة ما بين التشغيل و الإيقاف&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="282"/>
        <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
        <translation>&lt;h4&gt;إلتقط إطارًا (Space)&lt;/h4&gt; &lt;p&gt;اضغط هذا الزرّ &lt;em&gt;لالتقاط&lt;/em&gt; صورة من الكاميرا و إدراجها في التحريك&lt;/p&gt; &lt;p&gt; يمكن فعل ذلك كذلك بضغط &lt;b&gt;مفتاح المسافة&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="290"/>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, thereby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation>عدد الصور&lt;h4&gt;&lt;p&gt;بتغيير قيمة هذا المنزلق يمكنك تعيين عدد الصور رجوعا في التحريك التي ينبغي مزجها مع الكامرا أو إن كنت في طور العرض فإنه يعيّن عدد الصور التي تُعرض.&lt;/p&gt;&lt;p&gt;بمزج الصور السابقة بما يظهر في الكامرا يمكنك بيسر مشاهدة ما ستبدو عليه اللقطة التالية بالنسبة إلى سابقتها و بذلك تصنع تحريكا أسلس!&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="311"/>
        <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;شغّل التحريك (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="314"/>
        <source>&lt;h4&gt;Stop animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;أوقف التحريك (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="317"/>
        <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;الإطار السابق (J, شمال)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="320"/>
        <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;الإطار اللاحق (L, يمين)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="323"/>
        <source>&lt;h4&gt;Previous scene (I)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;المشهد السابق (I)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="326"/>
        <source>&lt;h4&gt;Next scene (O)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;المشهد اللاحق (O)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="330"/>
        <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;كرّر التحريك (CTRL+L)&lt;/h4&gt; &lt;p&gt;بهذا الزر يمكنك اختيار ما إن كنت تريد تشغيل التحريك مرة أم تريد تكراره بلا توقف.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="415"/>
        <source>Notice</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="415"/>
        <source>Playback only currently works when running the grabber 
as a daemon. Go to the preferences menu (CTRL+P) to switch 
to running the image grabbing as a daemon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback only currently works when running the grabber 
as a deamon. Go to the preferences menu (CTRL+P) to switch 
to running the image grabbing as a deamon.</source>
        <translation type="obsolete">حاليا يعمل العرض و حسب أثناء تشغيل اللاقط في طور الجنيّ. يمكنك تشغيل لاقط الصور في طور الجنيّ من قائمة التفضيلات (CTRL+P)</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="230"/>
        <source>Auto</source>
        <translation>تلقائيا</translation>
    </message>
    <message>
        <source>Pr sec</source>
        <translation type="obsolete">في الثانية</translation>
    </message>
    <message>
        <source>Pr min</source>
        <translation type="obsolete">في الدقيقة</translation>
    </message>
    <message>
        <source>Pr hr</source>
        <translation type="obsolete">في الساعة</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="275"/>
        <source>&lt;h4&gt;Launch Gimp&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in Gimp&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on Gimp&lt;/p&gt;</source>
        <translation>&lt;h4&gt;شغّل گِمب&lt;/h4&gt; &lt;p&gt;اضغط هذا الزر لفتح الإطار المعروض في برمجية تحرير الصور گِمب&lt;/p&gt; &lt;p&gt;لاحظ أنه يمكن كذلك سحب الصور من شريط الصور إلى گِمب مباشرة&lt;/p&gt;</translation>
    </message>
</context>
</TS>
